@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
 import getpass
 import json
 import logging
@@ -67,12 +66,13 @@ class ProfitBricksService(object):
             headers = dict()
         self._config = None
         self._config_filename = None
-        self.username = self._get_username(username, use_config, config_filename)
-        self.password = self._get_password(password, use_config, config_filename, use_keyring)
+        self.keyring_identificator = '%s (%s)' % (re.sub("/v\d+$", '', host_base), _LIBRARY_NAME)
         self.host_base = host_base
         self.host_cert = host_cert
         self.verify = ssl_verify
         self.headers = headers
+        self.username = self._get_username(username, use_config, config_filename)
+        self.password = self._get_password(password, use_config, config_filename, use_keyring)
         self.user_agent = '{}/{}'.format(_LIBRARY_NAME, __version__)
         if client_user_agent:
             self.user_agent = client_user_agent + ' ' + self.user_agent
@@ -167,16 +167,16 @@ class ProfitBricksService(object):
 
         if not password and use_keyring:
             logger = logging.getLogger(__name__)
-            question = ("Please enter your password for {}: ".format(self.username))
+            question = ("Please enter your password for {} on {}: ".format(self.username, self.host_base))
             if HAS_KEYRING:
-                password = keyring.get_password(_LIBRARY_NAME, self.username)
+                password = keyring.get_password(self.keyring_identificator, self.username)
                 if password is None:
                     password = getpass.getpass(question)
                     try:
-                        keyring.set_password(_LIBRARY_NAME, self.username, password)
+                        keyring.set_password(self.keyring_identificator, self.username, password)
                     except keyring.errors.PasswordSetError as error:
                         logger.warning("Storing password in keyring '%s' failed: %s",
-                                       _LIBRARY_NAME, error)
+                                       self.keyring_identificator, error)
             else:
                 logger.warning("Install the 'keyring' Python module to store your password "
                                "securely in your keyring!")
@@ -2271,19 +2271,18 @@ class ProfitBricksService(object):
     def _perform_request(self, url, method='GET', data=None, headers=None):
         if headers is None:
             headers = dict()
-        headers.update({'Authorization': 'Basic %s' % (base64.b64encode(
-            self._b('%s:%s' % (self.username,
-                               self.password))).decode('utf-8'))})
+
+        auth = (self.username, self.password)
 
         url = self._build_url(url)
         headers.update({'User-Agent': self.user_agent})
         if method == 'POST' or method == 'PUT':
-            response = self._wrapped_request(method, url, data=data,
+            response = self._wrapped_request(method, url, auth=auth, data=data,
                                              headers=headers)
             headers.update({'Content-Type': 'application/json'})
         elif method == 'POST-ACTION-JSON' or method == 'POST-ACTION':
             headers.update({'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'})
-            response = self._wrapped_request('POST', url, data=data,
+            response = self._wrapped_request('POST', url, auth=auth, data=data,
                                              headers=headers)
             if response.status_code == 202 and method == 'POST-ACTION':
                 return True
@@ -2291,11 +2290,11 @@ class ProfitBricksService(object):
                 raise response.raise_for_status()
         elif method == 'PATCH':
             headers.update({'Content-Type': 'application/json'})
-            response = self._wrapped_request(method, url, data=data,
+            response = self._wrapped_request(method, url, auth=auth, data=data,
                                              headers=headers)
         else:
             headers.update({'Content-Type': 'application/json'})
-            response = self._wrapped_request(method, url, params=data,
+            response = self._wrapped_request(method, url, auth=auth, params=data,
                                              headers=headers)
             if method == 'DELETE':
                 if response.status_code == 202:
